==> proguard-core-9.0.0-sources.jar: proguard/analysis/cpa/jvm/state/JvmAbstractStateFactory.java <==
/*
 * ProGuardCORE -- library to process Java bytecode.
 *
 * Copyright (c) 2002-2022 Guardsquare NV
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package proguard.analysis.cpa.jvm.state;

import proguard.analysis.cpa.defaults.LatticeAbstractState;
import proguard.analysis.cpa.defaults.MapAbstractState;
import proguard.analysis.cpa.jvm.cfa.nodes.JvmCfaNode;
import proguard.analysis.cpa.jvm.state.heap.JvmHeapAbstractState;

/**
 * This interface contains a method creating a fresh instance of {@link JvmAbstractState}.
 *
 * @author Dmitry Ivanov
 */
public interface JvmAbstractStateFactory<StateT extends LatticeAbstractState<StateT>>
{
    /**
     * Returns an instance of JvmAbstractState.
     */
    default JvmAbstractState<StateT> createJvmAbstractState(JvmCfaNode programLocation,
                                                            JvmFrameAbstractState<StateT> frame,
                                                            JvmHeapAbstractState<StateT> heap,
                                                            MapAbstractState<String, StateT> staticFields)
    {
        return new JvmAbstractState<>(programLocation, frame, heap, staticFields);
    }
}

==> proguard-core-9.1.7-sources.jar: proguard/analysis/cpa/jvm/state/JvmAbstractStateFactory.java <==
/*
 * ProGuardCORE -- library to process Java bytecode.
 *
 * Copyright (c) 2002-2022 Guardsquare NV
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package proguard.analysis.cpa.jvm.state;

import proguard.analysis.cpa.defaults.LatticeAbstractState;
import proguard.analysis.cpa.defaults.MapAbstractState;
import proguard.analysis.cpa.jvm.cfa.nodes.JvmCfaNode;
import proguard.analysis.cpa.jvm.state.heap.JvmHeapAbstractState;

/**
 * This interface contains a method creating a fresh instance of {@link JvmAbstractState}.
 *
 * @author Dmitry Ivanov
 */
public interface JvmAbstractStateFactory<StateT extends LatticeAbstractState<StateT>> {
  /** Returns an instance of JvmAbstractState. */
  default JvmAbstractState<StateT> createJvmAbstractState(
      JvmCfaNode programLocation,
      JvmFrameAbstractState<StateT> frame,
      JvmHeapAbstractState<StateT> heap,
      MapAbstractState<String, StateT> staticFields) {
    return new JvmAbstractState<>(programLocation, frame, heap, staticFields);
  }
}
